use chrono::Local;
use std::fs::OpenOptions;
use std::io::Write;

pub fn file_logging(filename: &str) {
    let target = Box::new(
        OpenOptions::new()
            .write(true)
            .append(true)
            .create(true)
            .open(&filename)
            .expect(format!("Can't open log file (write/append/create): {}", &filename).as_str()),
    );

    env_logger::Builder::from_default_env()
        .target(env_logger::Target::Pipe(target))
        .format(|buf, record| {
            writeln!(
                buf,
                "[{} {:5} {}:{}] {}",
                Local::now().format("%Y-%m-%d %H:%M:%S%.3f"),
                record.level(),
                record.file().unwrap_or("unknown"),
                record.line().unwrap_or(0),
                record.args()
            )
        })
        .filter_level(log::LevelFilter::Trace)
        .init();
}
