mod logging;

mod schema;
mod models;

use diesel::sqlite::SqliteConnection;
use diesel::prelude::*;
use dotenvy::dotenv;
use models::create_user;
use std::env;

pub fn establish_connection() -> SqliteConnection {
    dotenv().ok();

    let database_url = env::var("DATABASE_URL").expect("DATABASE_URL must be set");
    SqliteConnection::establish(&database_url)
        .unwrap_or_else(|_| panic!("Error connecting to {}", database_url))
}

fn main() {
    crate::logging::file_logging("lunarbbs.log");
    log::debug!("Hello World!");

    use self::schema::users::dsl::*;
    use self::models::User;

    let connection = &mut establish_connection();
    let results = users
        //.filter(published.eq(true))
        .limit(5)
        .select(User::as_select())
        .load(connection)
        .expect("Error loading users");

    println!("Displaying {} users", results.len());
    for u in results.iter() {
        println!("{}, {}", u.id, u.handle);
        println!("{} ({})\n", u.password, u.password_cost());
    }
    if results.len() == 0 {
        let u = create_user(connection, &"Test Dummy".to_string(), &"12345".to_string());
        println!("NEW USER");
        println!("{}, {}", u.id, u.handle);
        println!("{} ({})\n", u.password, u.password_cost());
    }
}
